class Domain(object):

    """Manage Domains.

    Args:
        name: domain name
    """

    def __init__(self, name, client):
        self.name = name
        self.client = client

    def retrieve(self, options={}):
        """Returns a single domain.

        '/domains/:name/' GET
        """
        body = options['query'] if 'query' in options else {}

        response = self.client.get('/domains/' + self.name + '/', body, options)

        return response

    def update(self, name, options={}):
        """Updates a single domain.

        '/domains/:name/' PUT

        Args:
            name: Domain Name
        """
        body = options['body'] if 'body' in options else {}
        body['name'] = name

        response = self.client.put('/domains/' + self.name + '/', body, options)

        return response

    def destroy(self, options={}):
        """Destroys a single domain.

        '/domains/:name/' DELETE
        """
        body = options['body'] if 'body' in options else {}

        response = self.client.delete('/domains/' + self.name + '/', body, options)

        return response

    def create(self, name, options={}):
        """Creates a single domain.

        '/domains/' POST

        Args:
            name: Domain Name
        """
        body = options['body'] if 'body' in options else {}
        body['name'] = name

        response = self.client.post('/domains/', body, options)

        return response

