from .http_client import HttpClient

# Assign all the api classes
from .api.domain import Domain
from .api.ssh_key import SshKey
from .api.zone import Zone
from .api.account import Account


class Client(object):

    def __init__(self, auth={}, options={}):
        self.http_client = HttpClient(auth, options)

    def domain(self, name):
        """Manage Domains.

        Args:
            name: domain name
        """
        return Domain(name, self.http_client)

    def ssh_key(self, id):
        """Manage SSH Keys.

        Args:
            id: ID
        """
        return SshKey(id, self.http_client)

    def zone(self, domain):
        """Manage Zones.

        Args:
            domain: Domain Name 
        """
        return Zone(domain, self.http_client)

    def account(self):
        """Account Objects.
        """
        return Account(self.http_client)

